/** 
* @name VoiceTerminal - статус терминала 
* @desc Обработка состояния терминала 
* @version 4  
*/

const dev1 = Device("_UNIT_voiceterminal1", [
  {"name":"uptime", "note":"Времы работы", "type":"string", "val":""},
  {"name":"status", "note":"Состояние", "type":"string", "val":""},
  {"name":"updater", "note":"Обновления", "type":"string", "val":""},
  {"name":"set_volume", "note":"Громкость терминала", "type":"number", "val":50},
  {"name":"set_music_volume", "note":"Громкость плеера", "type":"number", "val":50},
  {"name":"last_update", "note":"Update", "type":"string", "val":""}
  ]);

const dev2 = Device("_UNIT_voiceterminal2", [
  {"name":"uptime", "note":"Времы работы", "type":"string", "val":""},
  {"name":"status", "note":"Состояние", "type":"string", "val":""},
  {"name":"updater", "note":"Обновление", "type":"string", "val":""},
  {"name":"set_volume", "note":"Громкость терминала", "type":"number", "val":50},
  {"name":"set_music_volume", "note":"Громкость плеера", "type":"number", "val":50},
  {"name":"last_update", "note":"Last update", "type":"string", "val":""}
  ]);

script({
  start(param) {
    let device = '';

    //Скрипт запускается плагином с параметрами
    if(param !== undefined) {
      const obj = JSON.parse(param);
      
      //Выбор устройства
      if(obj.terminal == "VT1") {
        device = dev1;
      }
      else if(obj.terminal == "VT2") {
        device = dev2;
      }
    
      //Конвертация времени из секунд в часы
      let days = Math.floor(obj.uptime/86400);
      let hours = Math.floor((obj.uptime % 86400)/3600);
      let minutes = Math.floor((obj.uptime % 3600)/60);
      let seconds = obj.uptime % 60;
      let time = days+ "d " +((hours < 10) ? "0" : "")+hours+ ":" +((minutes < 10) ? "0" : "")+minutes+ ":" +((seconds < 10) ? "0" : "")+seconds;
      
      //Обновление параметров устройства
      if(obj.uptime !== undefined)
      device.setParam("uptime", time);
      
      if(obj.status !== undefined)
      device.setParam("status", obj.status);
      
      if(obj.updater !== undefined)
      device.setParam("updater", obj.updater);
      
      if(obj.volume !== undefined)
      device.setParam("set_volume", obj.volume);
      
      if(obj.music_volume !== undefined)
      device.setParam("set_music_volume", obj.music_volume);
      
      device.setParam("last_update", this.GetDate());
    }
  },
  
  GetDate() {
    return new Date().toLocaleString('ru-RU');
  }
});
